@@ -31,7 +31,7 @@ def static(path):
 from django.template.defaultfilters import addslashes
 from django.template.defaultfilters import capfirst
 from django.utils.html import escapejs as escapejs_filter
-from django.utils.html import fix_ampersands as fix_ampersands_filter
+# from django.utils.html import fix_ampersands as fix_ampersands_filter
 from django.template.defaultfilters import floatformat
 from django.template.defaultfilters import iriencode
 from django.template.defaultfilters import linenumbers
@@ -39,6 +39,7 @@ from django.template.defaultfilters import make_list
 from django.template.defaultfilters import stringformat
 from django.template.defaultfilters import title
 from django.template.defaultfilters import truncatechars
+from django.template.defaultfilters import truncatechars_html
 from django.template.defaultfilters import truncatewords
 from django.template.defaultfilters import truncatewords_html
 from django.template.defaultfilters import upper
@@ -54,7 +55,6 @@ from django.template.defaultfilters import center
 from django.template.defaultfilters import cut
 from django.template.defaultfilters import linebreaks_filter
 from django.template.defaultfilters import linebreaksbr
-from django.template.defaultfilters import removetags
 from django.template.defaultfilters import striptags
 from django.template.defaultfilters import join
 from django.template.defaultfilters import length
@@ -80,7 +80,8 @@ except ImportError:
 def slugify(value):
     return djslugify(force_text(value))
 
-
+from functools import partial
+linebreaksbr = partial(linebreaksbr, autoescape=True)
 
 # TZ
 
